<?php
/**
 * Shortcode Handler
 *
 * @package um_ext\um_social_login\core
 */

namespace um_ext\um_social_login\core;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class Social_Login_Shortcode
 */
class Social_Login_Shortcode {

	/**
	 * Social_Login_Shortcode constructor.
	 */
	public function __construct() {
		add_shortcode( 'ultimatemember_social_login', array( &$this, 'ultimatemember_social_login' ) );
		add_filter( 'um_registration_user_role', array( &$this, 'change_registration_role' ), 10, 2 );
	}

	/**
	 * Social Login Shortcode
	 *
	 * @param array $args attributes.
	 * @return string
	 */
	public function ultimatemember_social_login( $args = array() ) {
		wp_enqueue_script( 'um-social-login' );
		wp_enqueue_style( 'um-social-login' );

		$sso_session = UM()->Social_Login_API()->hybridauth()->getSession();
		if ( empty( $sso_session ) ) {
			return '';
		}

		$key = wp_generate_password( 5, false );

		if ( ! um_is_core_page( 'login' ) || ! $sso_session->get( '_um_shortcode_id' ) ) {
			$sso_session->set( '_um_shortcode_id', $key );
			foreach ( $_SESSION as $k => $value ) {
				if ( strpos( $k, '_um_social_login_key_' ) === 0 ) {
					$sso_session->set( $k, null );
				}
			}
		}
		$sso_session->set( '_um_social_login_key_' . $key, $args['id'] );

		$redirect_url = UM()->permalinks()->get_current_url();
		$redirect_url = remove_query_arg( array( 'code', 'state' ), $redirect_url );

		$sso_session->set( 'um_social_login_redirect', $redirect_url );
		$sso_session->set( 'um_social_login_rememberme', get_post_meta( $args['id'], '_um_keep_signed_in', true ) );

		UM()->Social_Login_API()->shortcode_id = $key;

		return $this->load( $args );
	}

	/**
	 * Get shortcode post meta
	 *
	 * @param integer $id post ID.
	 *
	 * @return array
	 */
	public function get_meta( $id ) {
		$array = array();

		$meta = get_post_custom( $id );
		if ( $meta && is_array( $meta ) ) {
			foreach ( $meta as $k => $v ) {
				$k = str_replace( '_um_', '', $k );

				$array[ $k ] = $v[0];
			}
		}

		return $array;
	}

	/**
	 * Load a module with global function
	 *
	 * @param array $atts Attributes.
	 * @return string
	 */
	public function load( $atts ) {
		$networks     = apply_filters( 'um_social_login_networks_output', UM()->Social_Login_API()->available_networks() );
		$arr_settings = $this->get_meta( $atts['id'] );

		foreach ( $networks as $provider => $arr ) {
			if ( isset( $arr_settings[ 'enable_' . $provider ] ) && 0 === absint( $arr_settings[ 'enable_' . $provider ] ) ) {
				unset( $networks[ $provider ] );
			}
		}

		if ( ! $networks ) {
			return '';
		}

		$pairs = array(
			'id'                  => '',
			'show_for_members'    => 0,
			'show_icons'          => '',
			'show_labels'         => '',
			'padding'             => '',
			'margin'              => '',
			'class'               => '',
			'button_style'        => '',
			'button_padding'      => '',
			'button_min_width'    => '',
			'fontsize'            => '',
			'iconsize'            => '',
			'container_max_width' => '',
		);

		$filter_atts = array_merge( $arr_settings, $atts );

		$args = shortcode_atts( $pairs, $filter_atts );
		if ( '0' === $args['show_for_members'] && is_user_logged_in() ) {
			return '';
		}

		$t_args = array(
			'o_networks'          => $networks,
			'id'                  => $args['id'],
			'show_for_members'    => $args['show_for_members'],
			'show_icons'          => $args['show_icons'],
			'show_labels'         => $args['show_labels'],
			'padding'             => $args['padding'],
			'margin'              => $args['margin'],
			'class'               => $args['class'],
			'button_style'        => $args['button_style'],
			'button_padding'      => $args['button_padding'],
			'button_min_width'    => $args['button_min_width'],
			'fontsize'            => $args['fontsize'],
			'iconsize'            => $args['iconsize'],
			'container_max_width' => $args['container_max_width'],
		);
		$output = UM()->get_template( 'buttons.php', um_social_login_plugin, $t_args );

		return $output;
	}

	/**
	 * Additional arguments for user registration
	 *
	 * @param string $role Role slug.
	 * @param array  $args Field settings.
	 *
	 * @return string
	 */
	public function change_registration_role( $role, $args ) {
		$sso_session = UM()->Social_Login_API()->hybridauth()->getSession();
		if ( empty( $sso_session ) ) {
			return $role;
		}

		$shortcode_id = sanitize_key( $sso_session->get( 'um_sso' ) );
		if ( $shortcode_id && isset( $_REQUEST['return_provider'] ) ) { // phpcs:ignore WordPress.Security.NonceVerification
			$assigned_role = get_post_meta( absint( $shortcode_id ), '_um_assigned_role', true );

			if ( ! empty( $assigned_role ) ) {
				$role = $assigned_role;
			}
		}

		return $role;
	}
}
